==> jsx-dom-runtime-0.68.0.tgz: package/jsx-runtime/index.js <==
const svgNs = 'http://www.w3.org/2000/svg';
const xhtmlNs = 'http://www.w3.org/1999/xhtml';
const mathmlNs = 'http://www.w3.org/1998/Math/MathML';
const properties = new Set(['value']);
const internalKeys = new Set(['_', 'children', 'ref']);
const extensions = new Map([['style', (node, value, key) => {
  if ('string' == typeof value) {
    node.setAttribute(key, value);
  } else {
    for (key in value) {
      if (key.startsWith('-')) {
        node.style.setProperty(key, value[key]);
      } else {
        node.style[key] = value[key];
      }
    }
  }
}], ['$', (node, value, key) => {
  for (key in value) {
    node.addEventListener(key, value[key]);
  }
}]]);
const appendChildren = (content, node) => {
  if (Array.isArray(content)) {
    content.some(i => appendChildren(i, node));
  } else if (false !== content && null != content) {
    node.append(content);
  }
};
const Fragment = content => {
  appendChildren(content, content = new DocumentFragment());
  return content;
};
const jsx = (tag, props) => {
  let key,
    value,
    node = props._ ? document.createElementNS(props._, tag) : document.createElement(tag, props.is ? {
      is: props.is
    } : key);
  for (key in props) {
    if (!internalKeys.has(key)) {
      value = props[key];
      if (extensions.has(key)) {
        extensions.get(key)(node, value, key);
      } else if (properties.has(key) || key.startsWith('on')) {
        node[key] = value;
      } else if (null != value) {
        if ('boolean' != typeof value || key.startsWith('-', 4)) {
          node.setAttribute(key, value);
        } else if (value) {
          node.setAttribute(key, '');
        }
      }
    }
  }
  appendChildren(props.children, 'template' == tag ? node.content : node);
  if (value = props.ref) {
    if ('function' == typeof value) {
      value(node);
    } else {
      value.current = node;
    }
  }
  return node;
};

const useRef = current => ({
  current
});

const parseFromString = html => {
  const template = jsx('template', {});
  template.innerHTML = html;
  return template.content;
};
const Template = props => parseFromString(props.children);

const useText = initContent => {
  const text = new Text(initContent);
  return [text, content => {
    if (initContent !== content) {
      text.textContent = initContent = content;
    }
  }];
};

export { Fragment, Template, appendChildren, extensions, jsx, mathmlNs, parseFromString, properties, svgNs, useRef, useText, xhtmlNs };

==> jsx-dom-runtime-0.70.0.tgz: package/jsx-runtime/index.js <==
const svgNs = 'http://www.w3.org/2000/svg';
const mathmlNs = 'http://www.w3.org/1998/Math/MathML';
const properties = new Set(['value']);
const internalKeys = new Set(['_', 'children', 'ref']);
const extensions = new Map([['style', (node, value, key) => {
  if ('string' == typeof value) {
    node.setAttribute(key, value);
  } else {
    for (key in value) {
      if (key.startsWith('-')) {
        node.style.setProperty(key, value[key]);
      } else {
        node.style[key] = value[key];
      }
    }
  }
}], ['$', (node, value, key) => {
  for (key in value) {
    node.addEventListener(key, value[key]);
  }
}]]);
const appendChildren = (content, node) => {
  if (Array.isArray(content)) {
    content.some(i => appendChildren(i, node));
  } else if (false !== content && null != content) {
    node.append(content);
  }
};
const Fragment = content => {
  appendChildren(content, content = new DocumentFragment());
  return content;
};
const jsx = (tag, props) => {
  let key,
    value,
    node = props._ ? document.createElementNS(props._, tag) : document.createElement(tag, props.is ? {
      is: props.is
    } : key);
  for (key in props) {
    if (!internalKeys.has(key)) {
      value = props[key];
      if (extensions.has(key)) {
        extensions.get(key)(node, value, key);
      } else if (properties.has(key) || key.startsWith('on')) {
        node[key] = value;
      } else if (null != value) {
        if ('boolean' != typeof value || key.startsWith('-', 4)) {
          node.setAttribute(key, value);
        } else if (value) {
          node.setAttribute(key, '');
        }
      }
    }
  }
  appendChildren(props.children, 'template' == tag ? node.content : node);
  if (value = props.ref) {
    if ('function' == typeof value) {
      value(node);
    } else {
      value.current = node;
    }
  }
  return node;
};

const useRef = current => ({
  current
});

const parseFromString = html => /*#__PURE__*/jsx('template', {
  ref(node) {
    node.innerHTML = html;
  }
}).content;
const Template = props => /*#__PURE__*/parseFromString(props.children);

const useText = initContent => {
  const text = new Text(initContent);
  return [text, content => {
    if (initContent !== content) {
      text.textContent = initContent = content;
    }
  }];
};

export { Fragment, Template, appendChildren, extensions, jsx, mathmlNs, parseFromString, properties, svgNs, useRef, useText };
